@@ -1,6 +1,6 @@
 /***
 |TiddlyFileImporter|
-|Version|0.2|
+|Version|0.3|
 |Author|Ben Gillies|
 |Type|plugin|
 |Description|Upload a TiddlyWiki file to TiddlyWeb, and import the tiddlers.|
@@ -15,17 +15,19 @@ tiddlywebplugins.reflector
 (function($){
 if(!version.extensions.TiddlyFileImporter)
 { //# ensure that the plugin is only installed once
-	version.extensions.TiddlyFileImporter = { installed: true }
-};
+	version.extensions.TiddlyFileImporter = { installed: true };
+}
 
 config.macros.fileImport = {
 	reflectorURI: '/reflector',
 	incorrectTypeError: 'Incorrect File Type. You must upload a TiddlyWiki',
 	uploadLabel: 'Upload',
 	uploadLabelPrompt: 'Import tiddlers from this TiddlyWiki',
-	step1Text: 'Pick a TiddlyWiki file to Upload',
-	step1Subtext: 'In the next screen you will select the tiddlers to import.',
-	step1Title: 'Step 1: Upload a TiddlyWiki file',
+	step1FileText: 'File:',
+	step1URLText: 'URL:',
+	step1PostText: 'In the next screen you will select the tiddlers to import.',
+	step1Title: 'Step 1: Pick a TiddlyWiki to import',
+	step1TypeChooser: 'Import From:',
 	step3Html: '<input type="hidden" name="markList" />'
 		+ '<input type="hidden" checked="true" name="chkSync" />'
 		+ '<input type="hidden" name="chkSave" />'
@@ -46,10 +48,9 @@ config.macros.fileImport = {
 		markList.parentNode.insertBefore(uploadWrapper, markList);
 		uploadWrapper.setAttribute('refresh', 'macro');
 		uploadWrapper.getAttribute('macroName', 'fileImport');
-		$(uploadWrapper).append('<p>' + me.step1Text + '</p>');
-		$(uploadWrapper).append('<p>' + me.step1Subtext + '</p>');
 		var iframeName = 'reflectorImporter' + Math.random().toString();
 		me.createForm(uploadWrapper, wizard, iframeName);
+		$(uploadWrapper).append('<p>' + me.step1PostText + '</p>');
 		wizard.setValue('serverType', 'tiddlyweb');
 		wizard.setValue('adaptor', new config.adaptors.file());
 		wizard.setValue('host', config.defaultCustomFields['server.host']);
@@ -58,11 +59,33 @@ config.macros.fileImport = {
 			caption: me.uploadLabel,
 			tooltip: me.uploadLabelPrompt,
 			onClick: function() {
-				var iframe = $('<iframe name="' + iframeName + '" '
-					+ 'style="display: none" />').appendTo(uploadWrapper);
-				// set an onload ready to hijack the form
-				me.setOnLoad(uploadWrapper, wizard, iframe[0]);
-				wizard.formElem.submit();
+				if (wizard.importType == "file") {
+					var iframe = $('<iframe name="' + iframeName + '" '
+						+ 'style="display: none" />').appendTo(uploadWrapper);
+					// set an onload ready to hijack the form
+					me.setOnLoad(uploadWrapper, wizard, iframe[0]);
+					wizard.formElem.submit();
+				} else {
+					$.ajax({
+						url: "%0/reflector".format([
+							config.defaultCustomFields["server.host"]]),
+						type: "POST",
+						dataType: "text",
+						data: {
+							uri: $("input", ".importFrom", wizard.formElem).val()
+						},
+						success: function(data, txtStatus, xhr) {
+							wizard.POSTResponse = data;
+							me.importTiddlers(uploadWrapper, wizard);
+						},
+						error: function(xhr, txtStatus, error) {
+							displayMessage("There was an error fetching the "
+								+ 'url: ' + txtStatus);
+							me.restart(wizard);
+						}
+					});
+					return false;
+				}
 			}
 		}]);
 	},
@@ -74,18 +97,36 @@ config.macros.fileImport = {
 		form.enctype = 'multipart/form-data';
 		form.method = 'POST';
 		form.target = iframeName;
-		$(place).append('<input type="file" name="file" />');
+		onSelectChange = function(e) {
+			var changeTo = $(this).val();
+			if (changeTo == "file") {
+				$(".importFrom").html('%0 <input type="file" name="file" />'.
+					format([me.step1FileText]));
+				wizard.importType = "file";
+			} else {
+				$(".importFrom").html('%0 <input type="text" name="uri" />'.
+					format([me.step1URLText]));
+				wizard.importType = "uri";
+			}
+		};
+		$(place).append('<span>%0</span>'.format([me.step1TypeChooser])).
+			append($('<select><option value="file" selected="selected">file'
+				+ '<option value="uri">url</select>').change(onSelectChange)).
+			append('<div class="importFrom">%0<input type="file" name="file" />'.
+					format([me.step1FileText])
+				+ '</div>');
+		wizard.importType = "uri";
 	},
 
 	setOnLoad: function(place, wizard, iframe) {
-		var me = config.macros.fileImport
+		var me = config.macros.fileImport;
 		var loadHandler = function() {
 			me.importTiddlers.apply(this, [place, wizard, iframe]);
 		};
 		iframe.onload = loadHandler;
 		completeReadyStateChanges = 0;
 		iframe.onreadystatechange = function() {
-			if (++(completeReadyStaeChanges) == 3) {
+			if (++(completeReadyStateChanges) == 3) {
 				loadHandler();
 			}
 		}
@@ -93,16 +134,21 @@ config.macros.fileImport = {
 
 	importTiddlers: function(place, wizard, iframe) {
 		var tmpStore = new TiddlyWiki();
-		try {
-			var POSTedWiki= iframe.contentWindow
-				.document.documentElement.innerHTML;
-		} catch(e) {
-			displayMessage(config.macros.fileImport.incorrectTypeError);
-			config.macros.fileImport.restart(wizard);
-			return;
+		var POSTedWiki = "";
+		if (wizard.importType == "file") {
+			try {
+				POSTedWiki= iframe.contentWindow
+					.document.documentElement.innerHTML;
+			} catch(e) {
+				displayMessage(config.macros.fileImport.incorrectTypeError);
+				config.macros.fileImport.restart(wizard);
+				return;
+			}
+			// now we are done, so remove the iframe
+			$(iframe).remove();
+		} else {
+			POSTedWiki = wizard.POSTResponse;
 		}
-		// now we are done, so remove the iframe
-		$(iframe).remove();
 
 		tmpStore.importTiddlyWiki(POSTedWiki);
 		var newTiddlers = tmpStore.getTiddlers();
@@ -142,7 +188,7 @@ config.macros.importTiddlers.onGetTiddler = function(context, wizard) {
 			false, tiddler.created);
 		var remainingImports = wizard.getValue("remainingImports")-1;
 		wizard.setValue("remainingImports",remainingImports);
-		if(remainingImports == 0) {
+		if(remainingImports === 0) {
 			if(context.isSynchronous) {
 				store.notifyAll();
 				refreshDisplay();
